# Copyright start
# Copyright (C) 2008 - 2020 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end
i_password=$1
i_password_encrypted=$2
install_type=$3

f_config=/opt/cyops/configs/database/db_config.yml
f_default_config=/opt/cyops/configs/database/db_config.yml.default
f_conf_util=/opt/cyops/configs/scripts/confUtil.py

# set default user passwords
echo "setting default users..."
if `/usr/share/elasticsearch/bin/elasticsearch-keystore list | grep -q 'bootstrap.password'`; then
    echo "bootstrap password already set"
else
    printf $i_password | /usr/share/elasticsearch/bin/elasticsearch-keystore add "bootstrap.password"
fi

echo "updating certs"
if [ ! -f /etc/elasticsearch/server.leaf.crt ]; then
    yes | cp /etc/pki/cyops/server.leaf.crt /etc/elasticsearch/server.leaf.crt
    yes | cp /etc/pki/cyops/server.leaf.key /etc/elasticsearch/server.leaf.key
    chmod g=u /etc/elasticsearch/server.leaf.*
fi

# enable security
if grep -Fxq "xpack.security.enabled:  true" /etc/elasticsearch/elasticsearch.yml
then
    echo "security is already enabled for elasticsearch"
else
    echo "enabling security for elasticsearch"
    echo "xpack.security.enabled:  true" >> /etc/elasticsearch/elasticsearch.yml
fi

if grep -Fxq "xpack.security.http.ssl.enabled: true" /etc/elasticsearch/elasticsearch.yml
then
    echo "ssl is already enabled for elasticsearch"
else
    echo "enabling ssl for elasticsearch"
    echo "xpack.security.http.ssl.enabled: true" >> /etc/elasticsearch/elasticsearch.yml
    echo "xpack.security.http.ssl.key: /etc/elasticsearch/server.leaf.key" >> /etc/elasticsearch/elasticsearch.yml
    echo "xpack.security.http.ssl.certificate: /etc/elasticsearch/server.leaf.crt" >> /etc/elasticsearch/elasticsearch.yml
fi

modify_elastic_config(){
    config_file=$1
    es_user_value=`python3 $f_conf_util -f $config_file -g es_user`
    if [ "$es_user_value" = "None" ]; then
        python3 $f_conf_util -f $config_file -k es_user -v elastic
        python3 $f_conf_util -f $config_file -k secret -v $i_password_encrypted
        python3 $f_conf_util -f $config_file -k use_ssl -v true
    fi
}

if [ $install_type = "fresh" ]; then
    echo "This is fresh install. Updating db_config.yml file"
    modify_elastic_config $f_config
fi

if [ $install_type = "upgrade" ]; then
    node_id=`csadm license --get-device-uuid`
    csadm ha list-nodes --primary  | grep -q $node_id &> /dev/null
    if [ $? == 0 ];then
        echo "This is primary node. Updating db_config.yml file"
        modify_elastic_config $f_config

        echo "Propagating es password change to secondary nodes, if any"
        /bin/hamanager add-command --async --commandId 'update_es_credentials' --command "/opt/cyops-auth/utilities/ha/cmd_executor.py --command update-es-credentials --input-arg $i_password_encrypted"
    else
        echo "This is secondary node. updating db_config.yml.default file"
        modify_elastic_config $f_default_config
    fi
fi
python3 $f_conf_util -f $f_config -k use_ssl -v true

file="/etc/kibana/kibana.yml"
if [ ! -e $file ]; then
    exit 0;
fi
sed -i 's/\#elasticsearch.hosts: \["http:\/\/localhost:9200"\]/elasticsearch.hosts: \["https:\/\/localhost:9200"\]/g' $file
sed -i 's/\#elasticsearch\.ssl\.verificationMode: full/elasticsearch.ssl.verificationMode: none/g' $file
